Hawaii Appellate Court Opinions and Orders
Description: The official website of the Hawaii State Judiciary. Provides access to case records, forms, contact information and Appellate Court opinions
Keywords: hawaii judiciary, hawaii court, hawaii state judiciary, hawaii state court, hawaii court records, hawaii case records, hawaii court forms

Skip to main content | Skip to text menu

- General Information
  - Contact Information
  - Job Opportunities
  - Jury Service
  - Judiciary Overview
  - Court Administration
  - Business with Judiciary
- News & Reports
  - Press Releases
  - Legislative Update
  - Reports
  - In the Media
  - Oral Arguments
  - Media Guidelines
  - Speeches
- Self-Help
  - Court Forms
  - Traffic Cases
  - Self-Help Centers
  - Protective Orders
  - Mortgage Foreclosure
  - Small Claims
  - Regular Claims
  - Divorce
  - Landlord-Tenant Claims
  - Tips on Going to Court
- Services
  - ADA
  - Court Interpreting
  - Law Library
  - Mediation/ADR
  - Children's Justice Centers
  - Victim Services
  - Volunteer Settlement Master Process
  - Vehicle Tracker
- Courts
  - Supreme Court
  - Intermediate Court of Appeals
  - Circuit Court
  - District Court
  - Family Court
  - Land and Tax Appeal Courts
  - Administrative Adjudication
  - Commission on Judicial Conduct
  - Judicial Performance Reviews
  - Judicial Selection Commission
- Legal References
  - Search Court Records
  - Proposed Rules Changes
  - Supreme Court Various Orders
  - Opinions
  - Court Rules
  - Internet Resources
- Community Outreach
  - Civics Education
  - Volunteer Opportunities
  - Judiciary History Center
  - Divorce Law Seminar
  - Court Tours
  - Lunch 'N' Learn the Law
- Special Projects & Events
  - HOPE Probation
  - Girls Court

## I want to...

- Learn about the Courts
- Visit the Law Library
- See the Oral Argument Schedule
- Listen to an Oral Argument
- Read the Rules of Court
- Read Recent Appellate Opinions
- Request an ADA Accommodation
- Give Feedback

## Searches

- eCourt Kokua The Hawaii Judiciary is not affiliated with Sustain Technologies, Inc. or with eCourt®, which is a registered trademark of Sustain Technologies, Inc.
- Ho`ohiki For access to criminal and civil case information filed in the Circuit and Family courts and certain civil cases of the District Courts.
- Jobs Search for jobs at the Judiciary
- Efiling Case information.

## Status Updates

- Twitter Stream
- Facebook Fan Page
- YouTube Channel

#
Hawaii Appellate Court Opinions and Orders 2013

For 2009 and older, Case Number link will display content as an html page. PDF link will display a scanned image with file date stamp and judicial signatures. Beginning in 2010, Case Number link will display a scanned image with file date stamp and judicial signatures. ADA link will display an accessible file compatible with online reader devices.

Date | Ct. | Case Number | Case Name | Appealed From | Reporter Citation
--- | --- | --- | --- | --- | ---
05/23/2013 | S.Ct | SCWC-11-0000586 | State v. Ungounga (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 02/15/2013 [ada], 129 Haw. 106. Application for Writ of Certiorari, filed 04/12/2013. | Circuit Court, 1st Circuit |
05/23/2013 | ICA | CAAP-12-0000480 | State v. Faleta (mem.op., affirmed). | Family Court, 1st Circuit (Sexual Assault) |
05/22/2013 | S.Ct | SCWC-11-0000064 | State v. DeLeon (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 01/18/2013 [ada], 129 Haw. 29. Application for Writ of Certiorari, filed 04/15/2013. | Circuit Court, 1st Circuit |
05/22/2013 | ICA | CAAP-12-0000095 [ADA] | Alkire-Clemen v. Castle Medical Center (s.d.o., affirmed). | Land and Industrial Relations Appeal Board (Workers' Compenation) |
05/22/2013 | ICA | CAAP-12-0000535 | Mikelson v. United Services Automobile Association (Order Denyting Motion for Partial Reconsideration of Memorandum Opinion). ICA mem.op., filed 05/06/2013 [ada]. Defendant-Appellant United Services Automobile Association's Motion for Partial Reconsideration of Memorandum Opinon, filed 05/15/2013. | Circuit Court, 1st Circuit |

© 2008 Hawaii State Judiciary. All rights reserved.

Privacy Policy | Terms of Use | Accessibility Information